Structure
---------

Structure functions from the awkward-array API. Dedicated Dask
specific API documentation will be added here; for now please consult
the awkward-array API docs.

.. currentmodule:: dask_awkward

..
   .. autosummary::

      argcartesian
      argcombinations
      argsort
      broadcast_arrays
      cartesian
      combinations
      concatenate
      copy
      fill_none
      firsts
      flatten
      from_regular
      full_like
      isclose
      is_none
      local_index
      mask
      nan_to_num
      num
      ones_like
      packed
      pad_none
      ravel
      run_lengths
      singletons
      sort
      strings_astype
      to_regular
      unflatten
      unzip
      values_astype
      where
      with_field
      with_name
      with_parameter
      without_parameters
      zeros_like
      zip

   .. autofunction:: argcartesian
   .. autofunction:: argcombinations
   .. autofunction:: argsort
   .. autofunction:: broadcast_arrays
   .. autofunction:: cartesian
   .. autofunction:: combinations
   .. autofunction:: concatenate
   .. autofunction:: copy
   .. autofunction:: fill_none
   .. autofunction:: firsts
   .. autofunction:: flatten
   .. autofunction:: from_regular
   .. autofunction:: full_like
   .. autofunction:: isclose
   .. autofunction:: is_none
   .. autofunction:: local_index
   .. autofunction:: mask
   .. autofunction:: nan_to_num
   .. autofunction:: num
   .. autofunction:: ones_like
   .. autofunction:: packed
   .. autofunction:: pad_none
   .. autofunction:: ravel
   .. autofunction:: run_lengths
   .. autofunction:: singletons
   .. autofunction:: sort
   .. autofunction:: strings_astype
   .. autofunction:: to_regular
   .. autofunction:: unflatten
   .. autofunction:: unzip
   .. autofunction:: values_astype
   .. autofunction:: where
   .. autofunction:: with_field
   .. autofunction:: with_name
   .. autofunction:: with_parameter
   .. autofunction:: without_parameters
   .. autofunction:: zeros_like
   .. autofunction:: zip
